# Copyright (c) 2011 Cloudera, Inc. All rights reserved.

from cmf.monitor import jmx_beans
from cmf.monitor.json_metrics_utils import get_beans

class JsonParser(object):
  def __init__(self, json_dict):
    """
    May raise ParseError if the json structure is not what
    we expect.
    """
    self._json = json_dict
    beans = get_beans(self._json, set([jmx_beans.EVENT_STATS,
                                       jmx_beans.SMON_ROLE_PIPELINE]))
    self.event_stats = beans.get(jmx_beans.EVENT_STATS)
    self.role_stage = beans.get(jmx_beans.SMON_ROLE_PIPELINE)

#
# This is what the DN json looks like:
#
SAMPLE = r"""
{
  "beans" : [ {
    "name" : "java.lang:type=MemoryPool,name=CMS Old Gen",
    "modelerType" : "sun.management.MemoryPoolImpl",
    "Name" : "CMS Old Gen",
    "Type" : "HEAP",
    "Valid" : true,
    "CollectionUsage" : {
      "committed" : 0,
      "init" : 65404928,
      "max" : 85196800,
      "used" : 0
    },
    "CollectionUsageThreshold" : 0,
    "CollectionUsageThresholdCount" : 0,
    "MemoryManagerNames" : [ "ConcurrentMarkSweep" ],
    "PeakUsage" : {
      "committed" : 65404928,
      "init" : 65404928,
      "max" : 85196800,
      "used" : 16997432
    },
    "Usage" : {
      "committed" : 65404928,
      "init" : 65404928,
      "max" : 85196800,
      "used" : 16997432
    },
    "UsageThreshold" : 0,
    "UsageThresholdCount" : 0,
    "CollectionUsageThresholdExceeded" : true,
    "CollectionUsageThresholdSupported" : true,
    "UsageThresholdExceeded" : true,
    "UsageThresholdSupported" : true
  }, {
    "name" : "java.lang:type=Memory",
    "modelerType" : "sun.management.MemoryImpl",
    "Verbose" : false,
    "HeapMemoryUsage" : {
      "committed" : 85000192,
      "init" : 0,
      "max" : 104792064,
      "used" : 19721336
    },
    "NonHeapMemoryUsage" : {
      "committed" : 52822016,
      "init" : 24313856,
      "max" : 136314880,
      "used" : 52529480
    },
    "ObjectPendingFinalizationCount" : 0
  }, {
    "name" : "java.lang:type=MemoryPool,name=Code Cache",
    "modelerType" : "sun.management.MemoryPoolImpl",
    "Name" : "Code Cache",
    "Type" : "NON_HEAP",
    "Valid" : true,
    "CollectionUsage" : null,
    "MemoryManagerNames" : [ "CodeCacheManager" ],
    "PeakUsage" : {
      "committed" : 4521984,
      "init" : 2555904,
      "max" : 50331648,
      "used" : 4434624
    },
    "Usage" : {
      "committed" : 4521984,
      "init" : 2555904,
      "max" : 50331648,
      "used" : 4424576
    },
    "UsageThreshold" : 0,
    "UsageThresholdCount" : 0,
    "CollectionUsageThresholdSupported" : false,
    "UsageThresholdExceeded" : true,
    "UsageThresholdSupported" : true
  }, {
    "name" : "com.cloudera.cmf.event.publish:type=PipelineStageMXBean,stage=roleStageTSStore",
    "modelerType" : "com.cloudera.cmon.pipeline.PipelineStage",
    "StageName" : "roleStageTSStore",
    "EventsDropped" : 3,
    "EventsSkipped" : 0,
    "EventsForwarded" : 0,
    "EventsProcessed" : 39,
    "InputQueueSize" : 0,
    "InputQueueCapacity" : 4096
  }, {
    "name" : "java.lang:type=Runtime",
    "modelerType" : "sun.management.RuntimeImpl",
    "Name" : "17500@bigrig",
    "ClassPath" : "/tmp/agent/process/592-cloudera-mgmt-SERVICEMONITOR:/home/cleroy/.m2/repository/mysql/mysql-connector-java/5.1.15/mysql-connector-java-5.1.15.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/commons-fileupload-1.2.2.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/jopt-simple-3.2.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/jersey-server-1.4.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/commons-digester-1.8.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/commons-beanutils-core-1.8.0.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/spring-webmvc-3.0.4.RELEASE.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/jsp-api-2.1.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/aspectjrt-1.6.8.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/ecj-3.5.1.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/configgen-3.8.0-SNAPSHOT.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/snappy-java-1.0.3.2.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/hadoop-core-0.20.2-cdh3u2.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/jetty-6.1.26.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/jetty-server-7.3.1.v20110307.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/servlet-api-2.5-6.1.14.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/postgresql-9.0-801.jdbc4.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/jsp-2.1-jetty-6.1.26.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/avro-1.5.4.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/libthrift-0.5.0-cdh.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/jetty-servlet-7.3.1.v20110307.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/velocity-1.6.4.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/jetty-management-6.1.26.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/javassist-3.8.0.GA.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/ini4j-0.5.1.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/sshj-0.5.0.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/jsp-api-2.1-6.1.14.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/jamon-api-2.3.0.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/stax-api-1.0.1.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/ant-1.6.5.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/aopalliance-1.0.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/hbase-0.90.4-cdh3u2.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/slf4j-api-1.6.1.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/lucene-core-3.1.0.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/async-http-client-1.6.5.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/asm-3.1.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/hibernate-entitymanager-3.6.2.Final.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/httpclient-4.1.1.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/commons-math-2.2.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/spring-asm-3.0.4.RELEASE.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/jamon-runtime-2.3.1.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/jackson-jaxrs-1.5.5.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/spring-web-3.0.4.RELEASE.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/common-3.8.0-SNAPSHOT.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/ehcache-core-2.4.3.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/dom4j-1.6.1.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/jsp-2.1-6.1.14.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/mail-1.4.3.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/camel-spring-2.7.2.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/mx4j-3.0.1.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/guava-r09.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/c3p0-0.9.1.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/usertype.jodatime-1.8.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/hue-plugins-1.2.0-cdh3u2.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/mx4j-tools-3.0.1.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/jackson-core-asl-1.8.3.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/jetty-continuation-7.3.1.v20110307.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/servlet-api-2.5.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/jta-1.1.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/protocol-3.8.0-SNAPSHOT.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/jettison-1.1.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/commons-logging-1.1.1.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/usertype.spi-1.8.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/commons-management-1.0.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/persist-3.8.0-SNAPSHOT.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/jaxb-api-2.1.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/firehose-3.8.0-SNAPSHOT.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/event-query-3.8.0-SNAPSHOT.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/jersey-json-1.4.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/alfredo-0.1.4.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/camel-test-2.7.2.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/hibernate-jpa-2.0-api-1.0.0.Final.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/aspectjweaver-1.6.8.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/xstream-1.3.1.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/jets3t-0.6.1.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/jsp-api-2.1-glassfish-2.1.v20091210.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/event-common-3.8.0-SNAPSHOT.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/log4j-1.2.16.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/activation-1.1.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/zookeeper-3.3.3-cdh3u2.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/poi-3.7.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/jersey-core-1.4.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/spring-beans-3.0.4.RELEASE.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/spring-core-3.0.4.RELEASE.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/hsqldb-1.8.0.10.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/jetty-http-7.3.1.v20110307.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/commons-io-2.0.1.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/spring-security-web-3.0.4.RELEASE.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/commons-httpclient-3.1.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/descriptors-3.8.0-SNAPSHOT.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/camel-core-2.7.2.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/jamon-processor-2.3.3.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/commons-beanutils-1.7.0.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/slf4j-log4j12-1.6.1.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/spring-security-core-3.0.4.RELEASE.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/jruby-complete-1.6.0.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/hibernate-c3p0-3.6.2.Final.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/jetty-security-7.3.1.v20110307.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/xmlenc-0.52.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/jetty-util-6.1.26.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/commons-cli-1.2.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/netty-3.2.1.Final.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/avro-ipc-1.5.4.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/model-3.8.0-SNAPSHOT.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/spring-tx-3.0.4.RELEASE.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/spring-security-config-3.0.4.RELEASE.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/alertpublisher-3.8.0-SNAPSHOT.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/jetty-io-7.3.1.v20110307.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/httpcore-4.1.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/protobuf-java-2.3.0.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/commons-configuration-1.6.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/commons-logging-api-1.0.4.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/spring-aop-3.0.4.RELEASE.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/jetty-util-7.3.1.v20110307.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/event-publish-3.8.0-SNAPSHOT.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/jsr311-api-1.1.1.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/bcprov-jdk16-1.46.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/cglib-2.2.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/spring-context-support-3.0.4.RELEASE.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/jsp-2.1-glassfish-2.1.v20091210.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/antlr-2.7.6.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/commons-el-1.0.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/hibernate-core-3.6.2.Final.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/paranamer-2.3.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/jackson-mapper-asl-1.8.3.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/hibernate-commons-annotations-3.2.0.Final.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/bcpg-jdk16-1.46.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/camel-velocity-2.7.2.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/xpp3_min-1.1.4c.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/eventcatcher-3.8.0-SNAPSHOT.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/commons-lang-2.6.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/server-3.8.0-SNAPSHOT.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/joda-time-1.6.2.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/commons-collections-3.2.1.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/camel-mail-2.7.2.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/scm-client-3.8.0-SNAPSHOT.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/commons-net-1.4.1.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/spring-expression-3.0.4.RELEASE.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/jdbcdslog-1.0.6.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/commons-codec-1.4.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/jaxb-impl-2.1.12.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/core-3.1.1.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/servlet-api-2.5-20081211.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/spring-context-3.0.4.RELEASE.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/jackson-xc-1.5.5.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/headlamp-3.8.0-SNAPSHOT.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/oro-2.0.8.jar",
    "StartTime" : 1324504780089,
    "BootClassPath" : "/usr/lib/jvm/java-6-sun-1.6.0.26/jre/lib/resources.jar:/usr/lib/jvm/java-6-sun-1.6.0.26/jre/lib/rt.jar:/usr/lib/jvm/java-6-sun-1.6.0.26/jre/lib/sunrsasign.jar:/usr/lib/jvm/java-6-sun-1.6.0.26/jre/lib/jsse.jar:/usr/lib/jvm/java-6-sun-1.6.0.26/jre/lib/jce.jar:/usr/lib/jvm/java-6-sun-1.6.0.26/jre/lib/charsets.jar:/usr/lib/jvm/java-6-sun-1.6.0.26/jre/lib/modules/jdk.boot.jar:/usr/lib/jvm/java-6-sun-1.6.0.26/jre/classes",
    "LibraryPath" : "/usr/lib/jvm/java-6-sun-1.6.0.26/jre/lib/amd64/server:/usr/lib/jvm/java-6-sun-1.6.0.26/jre/lib/amd64:/usr/lib/jvm/java-6-sun-1.6.0.26/jre/../lib/amd64:/usr/java/packages/lib/amd64:/usr/lib64:/lib64:/lib:/usr/lib",
    "VmName" : "Java HotSpot(TM) 64-Bit Server VM",
    "VmVendor" : "Sun Microsystems Inc.",
    "VmVersion" : "20.1-b02",
    "BootClassPathSupported" : true,
    "InputArguments" : [ "-Xmx106420423", "-Xdebug", "-Xrunjdwp:server=y,transport=dt_socket,address=4000,suspend=n", "-XX:+UseConcMarkSweepGC", "-XX:+UseParNewGC", "-Dmgmt.log.file=mgmt-cmf-mgmt1-SERVICEMONITOR-localhost.log.out", "-Djava.awt.headless=true" ],
    "ManagementSpecVersion" : "1.2",
    "SpecName" : "Java Virtual Machine Specification",
    "SpecVendor" : "Sun Microsystems Inc.",
    "SpecVersion" : "1.0",
    "SystemProperties" : [ {
      "key" : "java.ext.dirs",
      "value" : "/usr/lib/jvm/java-6-sun-1.6.0.26/jre/lib/ext:/usr/java/packages/lib/ext"
    }, {
      "key" : "java.vm.specification.vendor",
      "value" : "Sun Microsystems Inc."
    }, {
      "key" : "user.timezone",
      "value" : "America/Los_Angeles"
    }, {
      "key" : "java.vm.vendor",
      "value" : "Sun Microsystems Inc."
    }, {
      "key" : "user.name",
      "value" : "cloudera-scm"
    }, {
      "key" : "java.vm.specification.name",
      "value" : "Java Virtual Machine Specification"
    }, {
      "key" : "user.dir",
      "value" : "/tmp/agent/process/592-cloudera-mgmt-SERVICEMONITOR"
    }, {
      "key" : "user.country",
      "value" : "US"
    }, {
      "key" : "user.language",
      "value" : "en"
    }, {
      "key" : "java.specification.version",
      "value" : "1.6"
    }, {
      "key" : "sun.cpu.endian",
      "value" : "little"
    }, {
      "key" : "java.home",
      "value" : "/usr/lib/jvm/java-6-sun-1.6.0.26/jre"
    }, {
      "key" : "sun.jnu.encoding",
      "value" : "UTF-8"
    }, {
      "key" : "file.separator",
      "value" : "/"
    }, {
      "key" : "java.vendor.url",
      "value" : "http://java.sun.com/"
    }, {
      "key" : "java.awt.graphicsenv",
      "value" : "sun.awt.X11GraphicsEnvironment"
    }, {
      "key" : "os.arch",
      "value" : "amd64"
    }, {
      "key" : "java.io.tmpdir",
      "value" : "/tmp"
    }, {
      "key" : "java.runtime.name",
      "value" : "Java(TM) SE Runtime Environment"
    }, {
      "key" : "java.awt.printerjob",
      "value" : "sun.print.PSPrinterJob"
    }, {
      "key" : "file.encoding",
      "value" : "UTF-8"
    }, {
      "key" : "java.version",
      "value" : "1.6.0_26"
    }, {
      "key" : "java.vendor.url.bug",
      "value" : "http://java.sun.com/cgi-bin/bugreport.cgi"
    }, {
      "key" : "java.vm.specification.version",
      "value" : "1.0"
    }, {
      "key" : "file.encoding.pkg",
      "value" : "sun.io"
    }, {
      "key" : "sun.java.command",
      "value" : "com.cloudera.cmon.firehose.Main --pipeline-type SERVICE_MONITORING"
    }, {
      "key" : "sun.java.launcher",
      "value" : "SUN_STANDARD"
    }, {
      "key" : "path.separator",
      "value" : ":"
    }, {
      "key" : "java.runtime.version",
      "value" : "1.6.0_26-b03"
    }, {
      "key" : "java.class.path",
      "value" : "/tmp/agent/process/592-cloudera-mgmt-SERVICEMONITOR:/home/cleroy/.m2/repository/mysql/mysql-connector-java/5.1.15/mysql-connector-java-5.1.15.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/commons-fileupload-1.2.2.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/jopt-simple-3.2.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/jersey-server-1.4.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/commons-digester-1.8.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/commons-beanutils-core-1.8.0.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/spring-webmvc-3.0.4.RELEASE.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/jsp-api-2.1.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/aspectjrt-1.6.8.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/ecj-3.5.1.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/configgen-3.8.0-SNAPSHOT.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/snappy-java-1.0.3.2.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/hadoop-core-0.20.2-cdh3u2.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/jetty-6.1.26.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/jetty-server-7.3.1.v20110307.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/servlet-api-2.5-6.1.14.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/postgresql-9.0-801.jdbc4.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/jsp-2.1-jetty-6.1.26.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/avro-1.5.4.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/libthrift-0.5.0-cdh.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/jetty-servlet-7.3.1.v20110307.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/velocity-1.6.4.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/jetty-management-6.1.26.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/javassist-3.8.0.GA.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/ini4j-0.5.1.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/sshj-0.5.0.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/jsp-api-2.1-6.1.14.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/jamon-api-2.3.0.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/stax-api-1.0.1.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/ant-1.6.5.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/aopalliance-1.0.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/hbase-0.90.4-cdh3u2.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/slf4j-api-1.6.1.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/lucene-core-3.1.0.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/async-http-client-1.6.5.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/asm-3.1.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/hibernate-entitymanager-3.6.2.Final.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/httpclient-4.1.1.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/commons-math-2.2.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/spring-asm-3.0.4.RELEASE.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/jamon-runtime-2.3.1.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/jackson-jaxrs-1.5.5.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/spring-web-3.0.4.RELEASE.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/common-3.8.0-SNAPSHOT.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/ehcache-core-2.4.3.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/dom4j-1.6.1.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/jsp-2.1-6.1.14.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/mail-1.4.3.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/camel-spring-2.7.2.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/mx4j-3.0.1.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/guava-r09.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/c3p0-0.9.1.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/usertype.jodatime-1.8.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/hue-plugins-1.2.0-cdh3u2.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/mx4j-tools-3.0.1.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/jackson-core-asl-1.8.3.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/jetty-continuation-7.3.1.v20110307.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/servlet-api-2.5.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/jta-1.1.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/protocol-3.8.0-SNAPSHOT.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/jettison-1.1.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/commons-logging-1.1.1.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/usertype.spi-1.8.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/commons-management-1.0.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/persist-3.8.0-SNAPSHOT.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/jaxb-api-2.1.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/firehose-3.8.0-SNAPSHOT.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/event-query-3.8.0-SNAPSHOT.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/jersey-json-1.4.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/alfredo-0.1.4.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/camel-test-2.7.2.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/hibernate-jpa-2.0-api-1.0.0.Final.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/aspectjweaver-1.6.8.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/xstream-1.3.1.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/jets3t-0.6.1.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/jsp-api-2.1-glassfish-2.1.v20091210.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/event-common-3.8.0-SNAPSHOT.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/log4j-1.2.16.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/activation-1.1.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/zookeeper-3.3.3-cdh3u2.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/poi-3.7.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/jersey-core-1.4.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/spring-beans-3.0.4.RELEASE.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/spring-core-3.0.4.RELEASE.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/hsqldb-1.8.0.10.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/jetty-http-7.3.1.v20110307.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/commons-io-2.0.1.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/spring-security-web-3.0.4.RELEASE.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/commons-httpclient-3.1.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/descriptors-3.8.0-SNAPSHOT.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/camel-core-2.7.2.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/jamon-processor-2.3.3.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/commons-beanutils-1.7.0.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/slf4j-log4j12-1.6.1.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/spring-security-core-3.0.4.RELEASE.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/jruby-complete-1.6.0.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/hibernate-c3p0-3.6.2.Final.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/jetty-security-7.3.1.v20110307.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/xmlenc-0.52.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/jetty-util-6.1.26.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/commons-cli-1.2.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/netty-3.2.1.Final.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/avro-ipc-1.5.4.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/model-3.8.0-SNAPSHOT.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/spring-tx-3.0.4.RELEASE.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/spring-security-config-3.0.4.RELEASE.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/alertpublisher-3.8.0-SNAPSHOT.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/jetty-io-7.3.1.v20110307.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/httpcore-4.1.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/protobuf-java-2.3.0.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/commons-configuration-1.6.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/commons-logging-api-1.0.4.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/spring-aop-3.0.4.RELEASE.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/jetty-util-7.3.1.v20110307.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/event-publish-3.8.0-SNAPSHOT.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/jsr311-api-1.1.1.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/bcprov-jdk16-1.46.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/cglib-2.2.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/spring-context-support-3.0.4.RELEASE.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/jsp-2.1-glassfish-2.1.v20091210.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/antlr-2.7.6.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/commons-el-1.0.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/hibernate-core-3.6.2.Final.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/paranamer-2.3.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/jackson-mapper-asl-1.8.3.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/hibernate-commons-annotations-3.2.0.Final.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/bcpg-jdk16-1.46.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/camel-velocity-2.7.2.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/xpp3_min-1.1.4c.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/eventcatcher-3.8.0-SNAPSHOT.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/commons-lang-2.6.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/server-3.8.0-SNAPSHOT.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/joda-time-1.6.2.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/commons-collections-3.2.1.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/camel-mail-2.7.2.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/scm-client-3.8.0-SNAPSHOT.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/commons-net-1.4.1.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/spring-expression-3.0.4.RELEASE.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/jdbcdslog-1.0.6.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/commons-codec-1.4.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/jaxb-impl-2.1.12.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/core-3.1.1.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/servlet-api-2.5-20081211.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/spring-context-3.0.4.RELEASE.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/jackson-xc-1.5.5.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/headlamp-3.8.0-SNAPSHOT.jar:/home/cleroy/git/starship/cmf/distribution/target/enterprise-distribution-3.8.0-SNAPSHOT-daemons/lib/oro-2.0.8.jar"
    }, {
      "key" : "os.name",
      "value" : "Linux"
    }, {
      "key" : "mgmt.log.file",
      "value" : "mgmt-cmf-mgmt1-SERVICEMONITOR-localhost.log.out"
    }, {
      "key" : "line.separator",
      "value" : "\n"
    }, {
      "key" : "os.version",
      "value" : "2.6.38-11-generic"
    }, {
      "key" : "net.sf.ehcache.skipUpdateCheck",
      "value" : "true"
    }, {
      "key" : "sun.arch.data.model",
      "value" : "64"
    }, {
      "key" : "java.class.version",
      "value" : "50.0"
    }, {
      "key" : "sun.io.unicode.encoding",
      "value" : "UnicodeLittle"
    }, {
      "key" : "java.vendor",
      "value" : "Sun Microsystems Inc."
    }, {
      "key" : "sun.boot.class.path",
      "value" : "/usr/lib/jvm/java-6-sun-1.6.0.26/jre/lib/resources.jar:/usr/lib/jvm/java-6-sun-1.6.0.26/jre/lib/rt.jar:/usr/lib/jvm/java-6-sun-1.6.0.26/jre/lib/sunrsasign.jar:/usr/lib/jvm/java-6-sun-1.6.0.26/jre/lib/jsse.jar:/usr/lib/jvm/java-6-sun-1.6.0.26/jre/lib/jce.jar:/usr/lib/jvm/java-6-sun-1.6.0.26/jre/lib/charsets.jar:/usr/lib/jvm/java-6-sun-1.6.0.26/jre/lib/modules/jdk.boot.jar:/usr/lib/jvm/java-6-sun-1.6.0.26/jre/classes"
    }, {
      "key" : "java.awt.headless",
      "value" : "true"
    }, {
      "key" : "java.vm.info",
      "value" : "mixed mode"
    }, {
      "key" : "javamelody.storage-directory",
      "value" : "javamelody_firehose"
    }, {
      "key" : "java.specification.name",
      "value" : "Java Platform API Specification"
    }, {
      "key" : "java.vm.name",
      "value" : "Java HotSpot(TM) 64-Bit Server VM"
    }, {
      "key" : "java.vm.version",
      "value" : "20.1-b02"
    }, {
      "key" : "sun.boot.library.path",
      "value" : "/usr/lib/jvm/java-6-sun-1.6.0.26/jre/lib/amd64"
    }, {
      "key" : "java.endorsed.dirs",
      "value" : "/usr/lib/jvm/java-6-sun-1.6.0.26/jre/lib/endorsed"
    }, {
      "key" : "sun.os.patch.level",
      "value" : "unknown"
    }, {
      "key" : "sun.cpu.isalist",
      "value" : ""
    }, {
      "key" : "user.home",
      "value" : "/home/cloudera-scm"
    }, {
      "key" : "java.library.path",
      "value" : "/usr/lib/jvm/java-6-sun-1.6.0.26/jre/lib/amd64/server:/usr/lib/jvm/java-6-sun-1.6.0.26/jre/lib/amd64:/usr/lib/jvm/java-6-sun-1.6.0.26/jre/../lib/amd64:/usr/java/packages/lib/amd64:/usr/lib64:/lib64:/lib:/usr/lib"
    }, {
      "key" : "java.specification.vendor",
      "value" : "Sun Microsystems Inc."
    }, {
      "key" : "sun.management.compiler",
      "value" : "HotSpot 64-Bit Tiered Compilers"
    } ],
    "Uptime" : 2366925
  }, {
    "name" : "java.lang:type=ClassLoading",
    "modelerType" : "sun.management.ClassLoadingImpl",
    "LoadedClassCount" : 6396,
    "UnloadedClassCount" : 0,
    "TotalLoadedClassCount" : 6396,
    "Verbose" : false
  }, {
    "name" : "java.lang:type=GarbageCollector,name=ConcurrentMarkSweep",
    "modelerType" : "sun.management.GarbageCollectorImpl",
    "LastGcInfo" : null,
    "CollectionCount" : 0,
    "CollectionTime" : 0,
    "Name" : "ConcurrentMarkSweep",
    "Valid" : true,
    "MemoryPoolNames" : [ "Par Eden Space", "Par Survivor Space", "CMS Old Gen", "CMS Perm Gen" ]
  }, {
    "name" : "java.lang:type=Threading",
    "modelerType" : "sun.management.ThreadImpl",
    "ThreadAllocatedMemoryEnabled" : true,
    "ThreadAllocatedMemorySupported" : true,
    "DaemonThreadCount" : 62,
    "PeakThreadCount" : 73,
    "CurrentThreadCpuTimeSupported" : true,
    "ObjectMonitorUsageSupported" : true,
    "SynchronizerUsageSupported" : true,
    "ThreadContentionMonitoringEnabled" : false,
    "ThreadContentionMonitoringSupported" : true,
    "ThreadCpuTimeEnabled" : true,
    "AllThreadIds" : [ 314, 312, 311, 138, 130, 123, 122, 115, 114, 107, 106, 99, 98, 91, 90, 84, 83, 82, 75, 74, 73, 66, 65, 64, 63, 62, 61, 60, 59, 58, 56, 55, 48, 47, 46, 45, 44, 42, 41, 40, 39, 38, 37, 36, 25, 35, 34, 33, 32, 30, 29, 28, 27, 26, 24, 23, 22, 21, 20, 19, 18, 17, 16, 15, 14, 13, 12, 5, 3, 2 ],
    "CurrentThreadCpuTime" : 10000000,
    "CurrentThreadUserTime" : 10000000,
    "ThreadCount" : 70,
    "TotalStartedThreadCount" : 265,
    "ThreadCpuTimeSupported" : true
  }, {
    "name" : "java.util.logging:type=Logging",
    "modelerType" : "java.util.logging.Logging",
    "LoggerNames" : [ "org.jboss.netty.channel.socket.nio.DefaultNioSocketChannelConfig", "org.jboss.netty.channel.socket.nio.NioServerSocketChannel", "org.jboss.netty.channel.DefaultChannelFuture", "org.jboss.netty.channel.socket.nio.NioServerSocketPipelineSink", "org.jboss.netty.channel.socket.nio.NioClientSocketPipelineSink", "org.jboss.netty.util.ThreadRenamingRunnable", "javax.management.misc", "javax.management", "org.jboss.netty.channel.socket.nio.NioWorker", "org.jboss.netty.channel.StaticChannelPipeline", "org.jboss.netty.channel.CompleteChannelFuture", "org.jboss.netty.channel.SimpleChannelHandler", "sun.awt.AppContext", "org.jboss.netty.channel.socket.nio.SelectorUtil", "org.jboss.netty.channel.DefaultChannelPipeline", "global", "org.jboss.netty.channel.socket.nio.NioProviderMetadata", "org.jboss.netty.channel.SimpleChannelUpstreamHandler", "javax.management.mbeanserver", "org.jboss.netty.channel.socket.nio.NioClientSocketChannel", "" ]
  }, {
    "name" : "com.cloudera.cmf.event.publish:type=EventStorePublisherWithRetryMXBean",
    "modelerType" : "com.cloudera.cmf.event.publish.EventStorePublisherWithRetry",
    "SendQueueSize" : 0,
    "SendQueueMaxSize" : 20000,
    "DropCount" : 0,
    "ExceptionCount" : 0,
    "PushbackCount" : 0,
    "SentCount" : 5
  }, {
    "name" : "java.lang:type=Compilation",
    "modelerType" : "sun.management.CompilationImpl",
    "Name" : "HotSpot 64-Bit Tiered Compilers",
    "CompilationTimeMonitoringSupported" : true,
    "TotalCompilationTime" : 17006
  }, {
    "name" : "com.mchange.v2.c3p0:type=C3P0Registry",
    "modelerType" : "com.mchange.v2.c3p0.management.C3P0RegistryManager",
    "NumPooledDataSources" : 1,
    "NumPoolsAllDataSources" : 1,
    "AllIdentityTokens" : [ "z8kflt8krd9brorhx66s|3f9f76a5", "z8kflt8krd9brorhx66s|1535d18b", "z8kflt8krd9brorhx66s|72bdec44" ],
    "AllIdentityTokenized" : "[com.mchange.v2.c3p0.PoolBackedDataSource@2e8d0265 [ connectionPoolDataSource -> com.mchange.v2.c3p0.WrapperConnectionPoolDataSource@553dbbad [ acquireIncrement -> 3, acquireRetryAttempts -> 30, acquireRetryDelay -> 1000, autoCommitOnClose -> false, automaticTestTable -> null, breakAfterAcquireFailure -> false, checkoutTimeout -> 0, connectionCustomizerClassName -> null, connectionTesterClassName -> com.mchange.v2.c3p0.impl.DefaultConnectionTester, debugUnreturnedConnectionStackTraces -> false, factoryClassLocation -> null, forceIgnoreUnresolvedTransactions -> false, identityToken -> z8kflt8krd9brorhx66s|3f9f76a5, idleConnectionTestPeriod -> 100, initialPoolSize -> 10, maxAdministrativeTaskTime -> 0, maxConnectionAge -> 0, maxIdleTime -> 100, maxIdleTimeExcessConnections -> 0, maxPoolSize -> 100, maxStatements -> 0, maxStatementsPerConnection -> 0, minPoolSize -> 10, nestedDataSource -> com.mchange.v2.c3p0.DriverManagerDataSource@51eca323 [ description -> null, driverClass -> null, factoryClassLocation -> null, identityToken -> z8kflt8krd9brorhx66s|1535d18b, jdbcUrl -> jdbc:mysql://localhost/cmon_db, properties -> {user=******, password=******, autocommit=true, release_mode=auto} ], preferredTestQuery -> null, propertyCycle -> 0, testConnectionOnCheckin -> false, testConnectionOnCheckout -> false, unreturnedConnectionTimeout -> 0, usesTraditionalReflectiveProxies -> false; userOverrides: {} ], dataSourceName -> null, factoryClassLocation -> null, identityToken -> z8kflt8krd9brorhx66s|72bdec44, numHelperThreads -> 3 ], com.mchange.v2.c3p0.DriverManagerDataSource@51eca323 [ description -> null, driverClass -> null, factoryClassLocation -> null, identityToken -> z8kflt8krd9brorhx66s|1535d18b, jdbcUrl -> jdbc:mysql://localhost/cmon_db, properties -> {user=******, password=******, autocommit=true, release_mode=auto} ], com.mchange.v2.c3p0.WrapperConnectionPoolDataSource@553dbbad [ acquireIncrement -> 3, acquireRetryAttempts -> 30, acquireRetryDelay -> 1000, autoCommitOnClose -> false, automaticTestTable -> null, breakAfterAcquireFailure -> false, checkoutTimeout -> 0, connectionCustomizerClassName -> null, connectionTesterClassName -> com.mchange.v2.c3p0.impl.DefaultConnectionTester, debugUnreturnedConnectionStackTraces -> false, factoryClassLocation -> null, forceIgnoreUnresolvedTransactions -> false, identityToken -> z8kflt8krd9brorhx66s|3f9f76a5, idleConnectionTestPeriod -> 100, initialPoolSize -> 10, maxAdministrativeTaskTime -> 0, maxConnectionAge -> 0, maxIdleTime -> 100, maxIdleTimeExcessConnections -> 0, maxPoolSize -> 100, maxStatements -> 0, maxStatementsPerConnection -> 0, minPoolSize -> 10, nestedDataSource -> com.mchange.v2.c3p0.DriverManagerDataSource@51eca323 [ description -> null, driverClass -> null, factoryClassLocation -> null, identityToken -> z8kflt8krd9brorhx66s|1535d18b, jdbcUrl -> jdbc:mysql://localhost/cmon_db, properties -> {user=******, password=******, autocommit=true, release_mode=auto} ], preferredTestQuery -> null, propertyCycle -> 0, testConnectionOnCheckin -> false, testConnectionOnCheckout -> false, unreturnedConnectionTimeout -> 0, usesTraditionalReflectiveProxies -> false; userOverrides: {} ]]",
    "AllPooledDataSources" : "[com.mchange.v2.c3p0.PoolBackedDataSource@2e8d0265 [ connectionPoolDataSource -> com.mchange.v2.c3p0.WrapperConnectionPoolDataSource@553dbbad [ acquireIncrement -> 3, acquireRetryAttempts -> 30, acquireRetryDelay -> 1000, autoCommitOnClose -> false, automaticTestTable -> null, breakAfterAcquireFailure -> false, checkoutTimeout -> 0, connectionCustomizerClassName -> null, connectionTesterClassName -> com.mchange.v2.c3p0.impl.DefaultConnectionTester, debugUnreturnedConnectionStackTraces -> false, factoryClassLocation -> null, forceIgnoreUnresolvedTransactions -> false, identityToken -> z8kflt8krd9brorhx66s|3f9f76a5, idleConnectionTestPeriod -> 100, initialPoolSize -> 10, maxAdministrativeTaskTime -> 0, maxConnectionAge -> 0, maxIdleTime -> 100, maxIdleTimeExcessConnections -> 0, maxPoolSize -> 100, maxStatements -> 0, maxStatementsPerConnection -> 0, minPoolSize -> 10, nestedDataSource -> com.mchange.v2.c3p0.DriverManagerDataSource@51eca323 [ description -> null, driverClass -> null, factoryClassLocation -> null, identityToken -> z8kflt8krd9brorhx66s|1535d18b, jdbcUrl -> jdbc:mysql://localhost/cmon_db, properties -> {user=******, password=******, autocommit=true, release_mode=auto} ], preferredTestQuery -> null, propertyCycle -> 0, testConnectionOnCheckin -> false, testConnectionOnCheckout -> false, unreturnedConnectionTimeout -> 0, usesTraditionalReflectiveProxies -> false; userOverrides: {} ], dataSourceName -> null, factoryClassLocation -> null, identityToken -> z8kflt8krd9brorhx66s|72bdec44, numHelperThreads -> 3 ]]",
    "AllIdentityTokenCount" : 3,
    "AllIdentityTokenizedCount" : 3,
    "AllPooledDataSourcesCount" : 1,
    "AllIdentityTokenizedStringified" : [ "com.mchange.v2.c3p0.PoolBackedDataSource@2e8d0265 [ connectionPoolDataSource -> com.mchange.v2.c3p0.WrapperConnectionPoolDataSource@553dbbad [ acquireIncrement -> 3, acquireRetryAttempts -> 30, acquireRetryDelay -> 1000, autoCommitOnClose -> false, automaticTestTable -> null, breakAfterAcquireFailure -> false, checkoutTimeout -> 0, connectionCustomizerClassName -> null, connectionTesterClassName -> com.mchange.v2.c3p0.impl.DefaultConnectionTester, debugUnreturnedConnectionStackTraces -> false, factoryClassLocation -> null, forceIgnoreUnresolvedTransactions -> false, identityToken -> z8kflt8krd9brorhx66s|3f9f76a5, idleConnectionTestPeriod -> 100, initialPoolSize -> 10, maxAdministrativeTaskTime -> 0, maxConnectionAge -> 0, maxIdleTime -> 100, maxIdleTimeExcessConnections -> 0, maxPoolSize -> 100, maxStatements -> 0, maxStatementsPerConnection -> 0, minPoolSize -> 10, nestedDataSource -> com.mchange.v2.c3p0.DriverManagerDataSource@51eca323 [ description -> null, driverClass -> null, factoryClassLocation -> null, identityToken -> z8kflt8krd9brorhx66s|1535d18b, jdbcUrl -> jdbc:mysql://localhost/cmon_db, properties -> {user=******, password=******, autocommit=true, release_mode=auto} ], preferredTestQuery -> null, propertyCycle -> 0, testConnectionOnCheckin -> false, testConnectionOnCheckout -> false, unreturnedConnectionTimeout -> 0, usesTraditionalReflectiveProxies -> false; userOverrides: {} ], dataSourceName -> null, factoryClassLocation -> null, identityToken -> z8kflt8krd9brorhx66s|72bdec44, numHelperThreads -> 3 ]", "com.mchange.v2.c3p0.DriverManagerDataSource@51eca323 [ description -> null, driverClass -> null, factoryClassLocation -> null, identityToken -> z8kflt8krd9brorhx66s|1535d18b, jdbcUrl -> jdbc:mysql://localhost/cmon_db, properties -> {user=******, password=******, autocommit=true, release_mode=auto} ]", "com.mchange.v2.c3p0.WrapperConnectionPoolDataSource@553dbbad [ acquireIncrement -> 3, acquireRetryAttempts -> 30, acquireRetryDelay -> 1000, autoCommitOnClose -> false, automaticTestTable -> null, breakAfterAcquireFailure -> false, checkoutTimeout -> 0, connectionCustomizerClassName -> null, connectionTesterClassName -> com.mchange.v2.c3p0.impl.DefaultConnectionTester, debugUnreturnedConnectionStackTraces -> false, factoryClassLocation -> null, forceIgnoreUnresolvedTransactions -> false, identityToken -> z8kflt8krd9brorhx66s|3f9f76a5, idleConnectionTestPeriod -> 100, initialPoolSize -> 10, maxAdministrativeTaskTime -> 0, maxConnectionAge -> 0, maxIdleTime -> 100, maxIdleTimeExcessConnections -> 0, maxPoolSize -> 100, maxStatements -> 0, maxStatementsPerConnection -> 0, minPoolSize -> 10, nestedDataSource -> com.mchange.v2.c3p0.DriverManagerDataSource@51eca323 [ description -> null, driverClass -> null, factoryClassLocation -> null, identityToken -> z8kflt8krd9brorhx66s|1535d18b, jdbcUrl -> jdbc:mysql://localhost/cmon_db, properties -> {user=******, password=******, autocommit=true, release_mode=auto} ], preferredTestQuery -> null, propertyCycle -> 0, testConnectionOnCheckin -> false, testConnectionOnCheckout -> false, unreturnedConnectionTimeout -> 0, usesTraditionalReflectiveProxies -> false; userOverrides: {} ]" ],
    "AllPooledDataSourcesStringified" : [ "com.mchange.v2.c3p0.PoolBackedDataSource@2e8d0265 [ connectionPoolDataSource -> com.mchange.v2.c3p0.WrapperConnectionPoolDataSource@553dbbad [ acquireIncrement -> 3, acquireRetryAttempts -> 30, acquireRetryDelay -> 1000, autoCommitOnClose -> false, automaticTestTable -> null, breakAfterAcquireFailure -> false, checkoutTimeout -> 0, connectionCustomizerClassName -> null, connectionTesterClassName -> com.mchange.v2.c3p0.impl.DefaultConnectionTester, debugUnreturnedConnectionStackTraces -> false, factoryClassLocation -> null, forceIgnoreUnresolvedTransactions -> false, identityToken -> z8kflt8krd9brorhx66s|3f9f76a5, idleConnectionTestPeriod -> 100, initialPoolSize -> 10, maxAdministrativeTaskTime -> 0, maxConnectionAge -> 0, maxIdleTime -> 100, maxIdleTimeExcessConnections -> 0, maxPoolSize -> 100, maxStatements -> 0, maxStatementsPerConnection -> 0, minPoolSize -> 10, nestedDataSource -> com.mchange.v2.c3p0.DriverManagerDataSource@51eca323 [ description -> null, driverClass -> null, factoryClassLocation -> null, identityToken -> z8kflt8krd9brorhx66s|1535d18b, jdbcUrl -> jdbc:mysql://localhost/cmon_db, properties -> {user=******, password=******, autocommit=true, release_mode=auto} ], preferredTestQuery -> null, propertyCycle -> 0, testConnectionOnCheckin -> false, testConnectionOnCheckout -> false, unreturnedConnectionTimeout -> 0, usesTraditionalReflectiveProxies -> false; userOverrides: {} ], dataSourceName -> null, factoryClassLocation -> null, identityToken -> z8kflt8krd9brorhx66s|72bdec44, numHelperThreads -> 3 ]" ],
    "C3p0Version" : "0.9.1"
  }, {
    "name" : "java.lang:type=GarbageCollector,name=ParNew",
    "modelerType" : "sun.management.GarbageCollectorImpl",
    "LastGcInfo" : {
      "GcThreadCount" : 11,
      "duration" : 3,
      "endTime" : 2352996,
      "id" : 45,
      "memoryUsageAfterGc" : [ {
        "key" : "CMS Perm Gen",
        "value" : {
          "committed" : 48300032,
          "init" : 21757952,
          "max" : 85983232,
          "used" : 48104904
        }
      }, {
        "key" : "Code Cache",
        "value" : {
          "committed" : 4521984,
          "init" : 2555904,
          "max" : 50331648,
          "used" : 4424576
        }
      }, {
        "key" : "CMS Old Gen",
        "value" : {
          "committed" : 65404928,
          "init" : 65404928,
          "max" : 85196800,
          "used" : 16997432
        }
      }, {
        "key" : "Par Eden Space",
        "value" : {
          "committed" : 17432576,
          "init" : 17432576,
          "max" : 17432576,
          "used" : 0
        }
      }, {
        "key" : "Par Survivor Space",
        "value" : {
          "committed" : 2162688,
          "init" : 2162688,
          "max" : 2162688,
          "used" : 1937760
        }
      } ],
      "memoryUsageBeforeGc" : [ {
        "key" : "CMS Perm Gen",
        "value" : {
          "committed" : 48300032,
          "init" : 21757952,
          "max" : 85983232,
          "used" : 48104904
        }
      }, {
        "key" : "Code Cache",
        "value" : {
          "committed" : 4521984,
          "init" : 2555904,
          "max" : 50331648,
          "used" : 4424576
        }
      }, {
        "key" : "CMS Old Gen",
        "value" : {
          "committed" : 65404928,
          "init" : 65404928,
          "max" : 85196800,
          "used" : 16997432
        }
      }, {
        "key" : "Par Eden Space",
        "value" : {
          "committed" : 17432576,
          "init" : 17432576,
          "max" : 17432576,
          "used" : 17432576
        }
      }, {
        "key" : "Par Survivor Space",
        "value" : {
          "committed" : 2162688,
          "init" : 2162688,
          "max" : 2162688,
          "used" : 1819536
        }
      } ],
      "startTime" : 2352993
    },
    "CollectionCount" : 45,
    "CollectionTime" : 386,
    "Name" : "ParNew",
    "Valid" : true,
    "MemoryPoolNames" : [ "Par Eden Space", "Par Survivor Space" ]
  }, {
    "name" : "java.lang:type=MemoryPool,name=Par Eden Space",
    "modelerType" : "sun.management.MemoryPoolImpl",
    "Name" : "Par Eden Space",
    "Type" : "HEAP",
    "Valid" : true,
    "CollectionUsage" : {
      "committed" : 17432576,
      "init" : 17432576,
      "max" : 17432576,
      "used" : 0
    },
    "CollectionUsageThreshold" : 0,
    "CollectionUsageThresholdCount" : 0,
    "MemoryManagerNames" : [ "ConcurrentMarkSweep", "ParNew" ],
    "PeakUsage" : {
      "committed" : 17432576,
      "init" : 17432576,
      "max" : 17432576,
      "used" : 17432576
    },
    "Usage" : {
      "committed" : 17432576,
      "init" : 17432576,
      "max" : 17432576,
      "used" : 1620544
    },
    "CollectionUsageThresholdExceeded" : true,
    "CollectionUsageThresholdSupported" : true,
    "UsageThresholdSupported" : false
  }, {
    "name" : "com.sun.management:type=HotSpotDiagnostic",
    "modelerType" : "sun.management.HotSpotDiagnostic",
    "DiagnosticOptions" : [ {
      "name" : "HeapDumpBeforeFullGC",
      "origin" : "DEFAULT",
      "value" : "false",
      "writeable" : true
    }, {
      "name" : "HeapDumpAfterFullGC",
      "origin" : "DEFAULT",
      "value" : "false",
      "writeable" : true
    }, {
      "name" : "HeapDumpOnOutOfMemoryError",
      "origin" : "DEFAULT",
      "value" : "false",
      "writeable" : true
    }, {
      "name" : "HeapDumpPath",
      "origin" : "DEFAULT",
      "value" : "",
      "writeable" : true
    }, {
      "name" : "CMSAbortablePrecleanWaitMillis",
      "origin" : "DEFAULT",
      "value" : "100",
      "writeable" : true
    }, {
      "name" : "CMSWaitDuration",
      "origin" : "DEFAULT",
      "value" : "2000",
      "writeable" : true
    }, {
      "name" : "PrintGC",
      "origin" : "DEFAULT",
      "value" : "false",
      "writeable" : true
    }, {
      "name" : "PrintGCDetails",
      "origin" : "DEFAULT",
      "value" : "false",
      "writeable" : true
    }, {
      "name" : "PrintGCDateStamps",
      "origin" : "DEFAULT",
      "value" : "false",
      "writeable" : true
    }, {
      "name" : "PrintGCTimeStamps",
      "origin" : "DEFAULT",
      "value" : "false",
      "writeable" : true
    }, {
      "name" : "PrintClassHistogramBeforeFullGC",
      "origin" : "DEFAULT",
      "value" : "false",
      "writeable" : true
    }, {
      "name" : "PrintClassHistogramAfterFullGC",
      "origin" : "DEFAULT",
      "value" : "false",
      "writeable" : true
    }, {
      "name" : "PrintClassHistogram",
      "origin" : "DEFAULT",
      "value" : "false",
      "writeable" : true
    }, {
      "name" : "PrintConcurrentLocks",
      "origin" : "DEFAULT",
      "value" : "false",
      "writeable" : true
    } ]
  }, {
    "name" : "com.mchange.v2.c3p0:type=PooledDataSource[z8kflt8krd9brorhx66s|72bdec44]",
    "modelerType" : "com.mchange.v2.c3p0.management.DynamicPooledDataSourceManagerMBean",
    "overrideDefaultPassword" : null,
    "statementCacheNumConnectionsWithCachedStatementsAllUsers" : 0,
    "dataSourceName" : "z8kflt8krd9brorhx66s|72bdec44",
    "threadPoolNumIdleThreads" : 3,
    "acquireRetryAttempts" : 30,
    "autoCommitOnClose" : false,
    "identityToken" : "z8kflt8krd9brorhx66s|72bdec44",
    "forceIgnoreUnresolvedTransactions" : false,
    "startTimeMillisDefaultUser" : 1324504784485,
    "breakAfterAcquireFailure" : false,
    "maxPoolSize" : 100,
    "idleConnectionTestPeriod" : 100,
    "user" : "cmon",
    "numIdleConnectionsDefaultUser" : 10,
    "numFailedCheckoutsDefaultUser" : 0,
    "numConnections" : 10,
    "numBusyConnections" : 0,
    "connectionCustomizerClassName" : null,
    "automaticTestTable" : null,
    "numFailedIdleTestsDefaultUser" : 2,
    "statementCacheNumStatementsDefaultUser" : 0,
    "effectivePropertyCycleDefaultUser" : 25.0,
    "maxIdleTime" : 100,
    "userOverrides" : "{}",
    "numConnectionsAllUsers" : 10,
    "numBusyConnectionsDefaultUser" : 0,
    "maxIdleTimeExcessConnections" : 0,
    "checkoutTimeout" : 0,
    "allUsers" : "[cmon]",
    "statementCacheNumConnectionsWithCachedStatementsDefaultUser" : 0,
    "usesTraditionalReflectiveProxies" : false,
    "maxAdministrativeTaskTime" : 0,
    "userOverridesAsString" : null,
    "driverClass" : null,
    "connectionTesterClassName" : "com.mchange.v2.c3p0.impl.DefaultConnectionTester",
    "maxStatements" : 0,
    "statementCacheNumCheckedOutDefaultUser" : 0,
    "statementCacheNumStatementsAllUsers" : 0,
    "numUnclosedOrphanedConnectionsDefaultUser" : 0,
    "debugUnreturnedConnectionStackTraces" : false,
    "testConnectionOnCheckout" : false,
    "numConnectionsDefaultUser" : 10,
    "acquireRetryDelay" : 1000,
    "overrideDefaultUser" : null,
    "threadPoolNumTasksPending" : 0,
    "threadPoolSize" : 3,
    "unreturnedConnectionTimeout" : 0,
    "acquireIncrement" : 3,
    "numThreadsAwaitingCheckoutDefaultUser" : 0,
    "threadPoolNumActiveThreads" : 0,
    "minPoolSize" : 10,
    "maxStatementsPerConnection" : 0,
    "statementCacheNumCheckedOutStatementsAllUsers" : 0,
    "testConnectionOnCheckin" : false,
    "numUserPools" : 1,
    "numFailedCheckinsDefaultUser" : 0,
    "numUnclosedOrphanedConnectionsAllUsers" : 0,
    "initialPoolSize" : 10,
    "upTimeMillisDefaultUser" : 2362540,
    "numUnclosedOrphanedConnections" : 0,
    "properties" : "{user=******, password=******, autocommit=true, release_mode=auto}",
    "loginTimeout" : 0,
    "numIdleConnectionsAllUsers" : 10,
    "maxConnectionAge" : 0,
    "factoryClassLocation" : null,
    "jdbcUrl" : "jdbc:mysql://localhost/cmon_db",
    "propertyCycle" : 0,
    "numBusyConnectionsAllUsers" : 0,
    "numIdleConnections" : 10,
    "numHelperThreads" : 3,
    "preferredTestQuery" : null,
    "description" : null
  }, {
    "name" : "java.lang:type=MemoryPool,name=CMS Perm Gen",
    "modelerType" : "sun.management.MemoryPoolImpl",
    "Name" : "CMS Perm Gen",
    "Type" : "NON_HEAP",
    "Valid" : true,
    "CollectionUsage" : {
      "committed" : 0,
      "init" : 21757952,
      "max" : 85983232,
      "used" : 0
    },
    "CollectionUsageThreshold" : 0,
    "CollectionUsageThresholdCount" : 0,
    "MemoryManagerNames" : [ "ConcurrentMarkSweep" ],
    "PeakUsage" : {
      "committed" : 48300032,
      "init" : 21757952,
      "max" : 85983232,
      "used" : 48104904
    },
    "Usage" : {
      "committed" : 48300032,
      "init" : 21757952,
      "max" : 85983232,
      "used" : 48104904
    },
    "UsageThreshold" : 0,
    "UsageThresholdCount" : 0,
    "CollectionUsageThresholdExceeded" : true,
    "CollectionUsageThresholdSupported" : true,
    "UsageThresholdExceeded" : true,
    "UsageThresholdSupported" : true
  }, {
    "name" : "java.lang:type=OperatingSystem",
    "modelerType" : "com.sun.management.UnixOperatingSystem",
    "MaxFileDescriptorCount" : 4096,
    "OpenFileDescriptorCount" : 193,
    "CommittedVirtualMemorySize" : 630296576,
    "FreePhysicalMemorySize" : 2182844416,
    "FreeSwapSpaceSize" : 8516530176,
    "ProcessCpuTime" : 45080000000,
    "TotalPhysicalMemorySize" : 8318742528,
    "TotalSwapSpaceSize" : 8516530176,
    "Name" : "Linux",
    "Version" : "2.6.38-11-generic",
    "AvailableProcessors" : 8,
    "Arch" : "amd64",
    "SystemLoadAverage" : 0.0
  }, {
    "name" : "java.lang:type=MemoryPool,name=Par Survivor Space",
    "modelerType" : "sun.management.MemoryPoolImpl",
    "Name" : "Par Survivor Space",
    "Type" : "HEAP",
    "Valid" : true,
    "CollectionUsage" : {
      "committed" : 2162688,
      "init" : 2162688,
      "max" : 2162688,
      "used" : 1937760
    },
    "CollectionUsageThreshold" : 0,
    "CollectionUsageThresholdCount" : 0,
    "MemoryManagerNames" : [ "ConcurrentMarkSweep", "ParNew" ],
    "PeakUsage" : {
      "committed" : 2162688,
      "init" : 2162688,
      "max" : 2162688,
      "used" : 2162688
    },
    "Usage" : {
      "committed" : 2162688,
      "init" : 2162688,
      "max" : 2162688,
      "used" : 1937760
    },
    "CollectionUsageThresholdExceeded" : true,
    "CollectionUsageThresholdSupported" : true,
    "UsageThresholdSupported" : false
  }, {
    "name" : "JMImplementation:type=MBeanServerDelegate",
    "modelerType" : "javax.management.MBeanServerDelegate",
    "MBeanServerId" : "bigrig_1324504784117",
    "SpecificationName" : "Java Management Extensions",
    "SpecificationVersion" : "1.4",
    "SpecificationVendor" : "Sun Microsystems",
    "ImplementationName" : "JMX",
    "ImplementationVersion" : "1.6.0_26-b03",
    "ImplementationVendor" : "Sun Microsystems"
  }, {
    "name" : "java.lang:type=MemoryManager,name=CodeCacheManager",
    "modelerType" : "sun.management.MemoryManagerImpl",
    "Name" : "CodeCacheManager",
    "Valid" : true,
    "MemoryPoolNames" : [ "Code Cache" ]
  } ]
}
"""
