// (c) Copyright 2011-2012 Cloudera, Inc. All rights reserved.
define([
	"cloudera/chart/TimeRange"
], function(TimeRange) {

/**
 * This is a set of helper methods for the charts.
 */
return {
updateOnTimeSelectionChange: function(chartSet, range, isCurrentMode) {
	// the chart's range has changed, update my highlighted selection.
	if (chartSet._setVisibleRange(range)) {
		var currentRange = new TimeRange(chartSet.firstDate, chartSet.lastDate);
		if (currentRange.contains(range)) {
			// we already have the data.
			chartSet.zoomTo(chartSet.firstVisibleDate, chartSet.lastVisibleDate);
		} else if (currentRange.intersects(range)) {
			// we already have some of the data.
			chartSet._checkRange(/*forceUpdate=*/false, isCurrentMode);
		} else {
			// we don't have any of the data,
			// need to remove existing data, and
			// recalculate how much to cache.
			chartSet.removeAllDataInRange(new TimeRange(chartSet.firstDate, chartSet.lastDate));
			var cacheFactor = chartSet.getCacheFactor();
			var cachedRange = chartSet.calculateRange(range.startDate, range.endDate, cacheFactor);
			chartSet._setCachedRange(cachedRange);
			chartSet._checkRange(/*forceUpdate=*/true, isCurrentMode);
		}
	}
},

/**
 * Resizes a chart to a new dimension.
 */
resize: function(chartSet, chartWidth, chartHeight) {
	var visibleCharts = chartSet.getVisibleCharts();
	var width = chartWidth;
	var height = chartHeight * visibleCharts.length;
	chartSet.chart.setSize(width, height);
},

/**
 * Determines the delta between the new list and the old list.
 *
 * @param oldItems - the old list.
 * @param newItems - the new list.
 * @param func - the function that returns true if two items are the same,
 * false if they are not.
 *
 * @return a data structure, {adds: [...], removes: [...]}, which describes
 * the minimum set of changes required to make the old list same as the new list.
 * adds contains what should be added, removes contains what should be removed.
 */
getAddRemoves: function(oldItems, newItems, func) {

	var removes = [];
	var i, j;
	var oldLen = 0;
	if (oldItems) {
		oldLen = oldItems.length;
	}

	for (i = 0; i < oldLen; i += 1) {
		var oldItem = oldItems[i];
		var found = false;
		var newLen = newItems.length;
		for (j = 0; j < newLen; j += 1) {
			var newItem = newItems[j];
			if (func(newItem, oldItem)) {
				found = true;
				break;
			}
		}
		if (found) {
			// keep the existing item by removing it from the adds list.
			newItems.splice(j, 1);
		} else {
			// we need to remove the old item.
			removes.push(oldItem);
		}
	}

	return {adds: newItems, removes: removes};
}
};
});
