// (c) Copyright 2011-2012 Cloudera, Inc. All rights reserved.
define([], function() {
	var numericChoices = [{
		label: "<",
		value: "LT"
	}, {
		label: "<=",
		value: "LTE"
	}, {
		label: "=",
		value: "EQ"
	}, {
		label: ">=",
		value: "GTE"
	}, {
		label: ">",
		value: "GT"
	}];

	var stringChoices = [{
		label: "equal to",
		value: "EQ"
	}, {
		label: "not equal to",
		value: "NE"
	}, {
		label: "like",
		value: "LIKE"
	}];

	var enumChoices = [{
		label: "is",
		value: "EQ"
	}];

	var allComparatorChoices = {
		"numeric" : numericChoices,
		"string" : stringChoices,
		"enum" : enumChoices
	};

	return function(options) {

		function Rule(name, comparator, value) {
			this.name = ko.observable(name);
			this.comparator = ko.observable(comparator);

			this.rule = ko.dependentObservable(function() {
				var name = this.name();
				return viewModel.searchRule(name);
			}, this);

			this.ruleType = ko.dependentObservable(function() {
				var result = "", rule = this.rule();
				if (rule) {
					 result = rule.type || "";
				}
				return result;
			}, this);

			var ruleType = this.ruleType();
			if (ruleType === 'enum') {
				this.selectValue = ko.observable(value);
				this.inputValue = ko.observable("");
			} else {
				this.selectValue = ko.observable("");
				this.inputValue = ko.observable(value);
			}

			this.value = ko.dependentObservable(function() {
				var result = "", ruleType = this.ruleType();
				if (ruleType === 'enum') {
					result = this.selectValue() || "";
				} else {
					result = this.inputValue() || "";
				}
				return result;
			}, this);

			this.comparatorChoices = ko.dependentObservable(function() {
				var result = [], rule = this.rule();
				if (rule) {
					 result = allComparatorChoices[rule.type] || [];
				}
				return result; 
			}, this);

			this.valueChoices = ko.dependentObservable(function() {
				var result = [], rule = this.rule();
				if (rule) {
					result = rule.valueChoices || [];
				}
				return result;
			}, this);

			this.isDefined = ko.dependentObservable(function() {
				return (this.rule() !== null);
			}, this);

			this.units = ko.dependentObservable(function() {
				var result = "", rule = this.rule();
				if (rule) {
					result = rule.units || "";
				}
				return result;
			}, this);

			this.removeSelf = function($this, evt) {
				viewModel.rules.remove(this);
				if (evt) {
					evt.preventDefault();
				}
			};

			this.insertBelow = function($this, evt) {
				var index = viewModel.rules.indexOf(this);
				var rule = viewModel.newRule("", "", "");
				viewModel.rules.splice(index + 1, 0, rule);
				if (evt) {
					evt.preventDefault();
				}
			};

			this.hasSiblings = function() {
				return viewModel.rules().length > 1;
			};

			this.inputName = ko.dependentObservable(function() {
				return "rule" + viewModel.rules.indexOf(this);
			}, this);
		}

		var viewModel = {
			rules : ko.observableArray(options.rules),
			ruleChoices: options.ruleChoices,
			searchRule: function(name) {
				var i, rule, result = null;
				for (i = 0; i < this.ruleChoices.length; i += 1) {
					rule = this.ruleChoices[i];
					if (rule.name === name) {
						result = rule;
						break;
					}
				}
				return result;
			},
			newRule: function(name, comparator, value) {
				return new Rule(name, comparator, value);
			}
		};

		return viewModel;
	};
});
