// Copyright (c) 2012 Cloudera, Inc.  All rights reserved.
define([
], function() {
	var watchedPaths = {};
	var selectedClass = "ui-state-highlight";
	var disabledClass = "ui-state-disabled";
	/**
	 * Controls Watched Directories on the browse page.
	 */
	return function(options) {
		var i;
		if (options.watchedDirs && options.watchedDirs.results) {
			for (i = 0; i < options.watchedDirs.results.length; i+=1) {
				var path = options.watchedDirs.results[i].path;
				watchedPaths[path] = true;
			}
		}

		/**
		 * A FileSearchResult data is rendered (hidden) in the row.
		 */
		var getDataFromEvent = function(evt) {
			var $target = $(evt.target);
			var dataStr = $target.closest("tr").find(".data").text();
			return $.parseJSON(dataStr);
		};

		/**
		 * Handles when the table is clicked.
		 */
		$("#" + options.tableId).click(function(evt) {
			var $target = $(evt.target);
			if (!$target.is(".watchedDir")) {
				$target = $target.closest(".watchedDir");
			}
			if ($target.length > 0) {
				var data = getDataFromEvent(evt);
				if ($target.hasClass(selectedClass)) {
					manager.removeDir(data.path, $target);
				} else {
					manager.addDir(data.path, $target);
				}
			}
		});

		var manager = {
			addDir: function(path, $elem) {
				var onAddSuccess = function(response) {
					watchedPaths[path] = true;
					$elem.addClass(selectedClass).removeClass(disabledClass);
				};

				var urlParams = {
					path: path
				};
				$.post(options.addWatchedDirUrl, urlParams, onAddSuccess);
			},
			
			removeDir: function(path, $elem) {
				var onRemoveSuccess = function(response) {
					delete watchedPaths[path];
					$elem.removeClass(selectedClass).addClass(disabledClass);
				};

				var urlParams = {
					path: path
				};
				$.post(options.removeWatchedDirUrl, urlParams, onRemoveSuccess);
			},

			isDirWatched: function(path) {
				return watchedPaths[path] === true;
			},

			renderIcon: function(path) {
				var watched = this.isDirWatched(path);
				var clazz = watched ? selectedClass : disabledClass;
				return '<div class="watchedDir ui-state-default ' + clazz + '"><span class="ui-icon ui-icon-star"></span></div>';
			}
		};

		return manager;
	};
	
});
