// (c) Copyright 2011-2012 Cloudera, Inc. All rights reserved.
define([
	"cloudera/Util"
], function(Util) {

describe("Util Tests", function() {

	it("should return the first chart color.", function() {
		expect(Util.getChartColor(0)).toEqual(Util.getChartColors()[0]);
	});

	it("should return a chart color within the array range.", function() {
		var colors = Util.getChartColors();
		var index = 1000;
		var actual = Util.getChartColor(index);
		var expected = colors[index % colors.length];
		expect(actual).toEqual(expected);
	});

	it("expects a very old server date.", function() {
		// set the server time to be something really old.
		Util.setServerNow(new Date(1));
		// after some short delay,
		var serverDate = Util.getServerNow();
		// expect the current server time to be something
		// really old as well.
		expect(serverDate.getTime()).toBeLessThan(1000);
	});

	it("should truncate text", function() {
		var text = "a very very long text";
		var actual = Util.truncate(text, 6);
		expect(actual).toEqual("a very...");
	});

	it("should find the right momentjs's language", function() {
		var locales = ["ko", "ja", "zh_CN", "zh_TW", "en", "en_AU", "en_US", "en_GB", "fr_FR", "fr", "it"];
		var expected = ["kr", "jp", "zh-cn", "zh-tw", "en", "en", "en", "en-gb", "fr", "fr", "it"];
		$.each(locales, function(i, locale) {
			var actual = Util.toMomentLanguage(locale);
			expect(actual).toEqual(expected[i]);
		});
	});

	it("should find the right jquery DatePicker's language", function() {
		var locales = ["ko", "ja", "zh_CN", "zh_TW", "en", "en_AU", "en_US", "en_GB", "fr_FR", "fr", "it", "pt", "pt_BR"];
		var expected = ["ko", "ja", "zh-CN", "zh-TW", "en", "en", "en", "en-GB", "fr", "fr", "it", "pt", "pt-BR"];
		$.each(locales, function(i, locale) {
			var actual = Util.toDatePickerLanguage(locale);
			expect(actual).toEqual(expected[i]);
		});
	});

	it("should set the correct momentjs's locale", function() {
		Util.setLocale("zh_CN");
		// Chinese version.
		expect("zh_CN").toEqual(Util.getLocale());
		expect("YYYY年MMMD日").toEqual(moment.longDateFormat.L);
		// UK version.
		Util.setLocale("en_GB");
		expect("en_GB").toEqual(Util.getLocale());
		expect("DD/MM/YYYY").toEqual(moment.longDateFormat.L);
		// US version.
		Util.setLocale("garbage");
		expect("MM/DD/YYYY").toEqual(moment.longDateFormat.L);
	});

	it("should be in test mode", function() {
		expect(Util.getTestMode()).toEqual(true);
	});

	it("should set/get the server timezone display name", function() {
		var oldDisplayName = Util.getServerTimezoneDisplayName();
		expect(Util.getServerTimezoneDisplayName()).toEqual(oldDisplayName);

		Util.setServerTimezoneDisplayName("blah");
		expect(Util.getServerTimezoneDisplayName()).toEqual("blah");

		Util.setServerTimezoneDisplayName(oldDisplayName);
	});

	it("should setServerTimezoneOffset only if the argument is numeric", function() {
		var oldTZOffset = Util.getServerTimezoneOffset();
		Util.setServerTimezoneOffset(10);
		expect(Util.getServerTimezoneOffset()).toEqual(10);
		Util.setServerTimezoneOffset("blah");
		expect(Util.getServerTimezoneOffset()).toEqual(10);
		Util.setServerTimezoneOffset(oldTZOffset);
	});

	function testFilterJsonResponseError(response, expectedMessage, expectedData) {
		var result = Util.filterJsonResponseError(response);
		expect(result.message).toEqual(expectedMessage);
		expect(result.data).toEqual(expectedData);
	}

	it("should handle JSON argument in filterJsonResponseError.", function() {
		var response = {
			message: "OK",
			data: "foo"
		};
		testFilterJsonResponseError(response, "OK", "foo");
	});

	it("should handle string argument in filterJsonResponseError.", function() {
		var response = JSON.stringify({
			message: "OK",
			data: "foo"
		});
		testFilterJsonResponseError(response, "OK", "foo");
	});

	it("should handle null argument in filterJsonResponseError.", function() {
		var response = null;
		testFilterJsonResponseError(response, undefined, undefined);
	});

	it("should handle undefined argument in filterJsonResponseError.", function() {
		var response;
		testFilterJsonResponseError(response, undefined, undefined);
	});

	it("should handle badly formatted JSON String in filterJsonResponseError.", function() {
		var response = "badly formatted JSON";
		testFilterJsonResponseError(response, undefined, undefined);
	});

});
});
